@@ -1,6 +1,6 @@
 package XML::MyXML;
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
-$XML::MyXML::VERSION = '0.9008';
+$XML::MyXML::VERSION = '0.9009';
 use strict;
 use warnings;
 use Carp;
@@ -474,7 +474,7 @@ sub check_xml {
 
 
 package XML::MyXML::Object;
-$XML::MyXML::Object::VERSION = '0.9008';
+$XML::MyXML::Object::VERSION = '0.9009';
 use Carp;
 use Encode;
 
@@ -565,7 +565,7 @@ sub path {
 		$self->cmp_element(shift @path)		or return;
 	}
 	for (my $i = 0; $i <= $#path; $i++) {
-		@result = $result[0]->children( $path[$i] );
+		@result = map $_->children( $path[$i] ), @result;
 		@result		or return;
 	}
 	return wantarray ? @result : $result[0];
@@ -695,7 +695,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.9008
+version 0.9009
 
 =head1 SYNOPSIS
 
